import greenfoot.*;

/**
 * A rocket that can be controlled by the arrowkeys: up, left, right.
 * The gun is fired by hitting the 'space' key. 'z' releases a proton wave.
 * 
 * @author Poul Henriksen
 * @author Michael Kölling
 * 
 * @version 1.1
 */
public class Submarine extends SmoothMover
{
    private static final int gunReloadTime = 5;         // The minimum delay between firing the gun.

    private int reloadDelayCount;               // How long ago we fired the gun the last time.

    /**
     * Initialise this rocket.
     */
    public Submarine()
    {
        GreenfootImage rocketImage = new GreenfootImage("Submarine.png");
        rocketImage.scale(90, 100);
        setImage(rocketImage);
        reloadDelayCount = 5;
        addToVelocity(new Vector(13, 0.7));
    }

    /**
     * Do what a rocket's gotta do. (Which is: mostly flying about, and turning,
     * accelerating and shooting when the right keys are pressed.)
     * 9.29-The act method calls the checkCollision method.
     */
    public void act()
    {
        move();
        checkKeys();
        checkCollision();
        reloadDelayCount++;
    }
    
    /**
     * Check whether there are any key pressed and react to them.
     */
    private void checkKeys() 
    {
        ignite(Greenfoot.isKeyDown("up"));
        if (Greenfoot.isKeyDown("space")) 
        {
            fire();
        } else if (Greenfoot.isKeyDown("left")) {
            turn(-5);
        } else if (Greenfoot.isKeyDown("right")) {
            turn(5);
        } else if (Greenfoot.isKeyDown("z")) {
           startProtonWave();
        }

    }
    
    /**
     * Fire a bullet if the gun is ready.
     */
    private void fire() 
    {
        if (reloadDelayCount >= gunReloadTime) 
        {
            Cannonball bullet = new Cannonball (getVelocity(), getRotation());
            getWorld().addObject (bullet, getX(), getY());
            bullet.move ();
            reloadDelayCount = 0;
        }
    }
    
    private void ignite(boolean isKeyDown) 
    {
        if (isKeyDown) 
        {
            addToVelocity(new Vector(getRotation(), 0.3));
        }
    }
    
    private void checkCollision() {
        Shark a =(Shark) getOneIntersectingObject(Shark.class);
        if (a != null) {
            // Body of the if statement
            Sea sea = (Sea) getWorld();
            sea.addObject(new Explosion(), getX(), getY());
            sea.removeObject(this);
            sea.gameOver();
        }
    }
    
    private void startProtonWave() {
        World world = getWorld();
        world.addObject(new ProtonWave(), getX(), getY());
    }
}